@@ -23,13 +23,6 @@ typedef uint32_t        uid_t;
 #endif
 
 #ifdef _MSC_VER
-typedef unsigned char   u_char;
-typedef unsigned short  u_short;
-typedef unsigned int    u_int;
-typedef uint32_t        in_addr_t;
-typedef uint32_t        mode_t;
-typedef uint32_t        uid_t;
-
 #include <basetsd.h>
 typedef SSIZE_T ssize_t;
 
